@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * atom.cc
  *
- * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,6 +27,7 @@
 #include "bond.h"
 #include "xml-utils.h"
 #include <cmath>
+#include <cstring>
 
 using namespace gcu;
 
@@ -150,8 +151,10 @@ xmlNodePtr Atom::Save(xmlDocPtr xml)
 	if (!parent) return NULL;
 	SaveId(parent);
 
-	strncpy(buf, GetSymbol(), sizeof(buf));
-	xmlNewProp(parent, (xmlChar*)"element", (xmlChar*)buf);
+	if (m_Z) {
+		strncpy(buf, GetSymbol(), sizeof(buf));
+		xmlNewProp(parent, (xmlChar*)"element", (xmlChar*)buf);
+	}
 	
 	if (m_Charge)
 	{
