@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * filechooser.h 
  *
- * Copyright (C) 2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,6 +28,7 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtkfilechooser.h>
 #include <list>
+#include <string>
 
 using namespace std;
 
@@ -37,10 +38,28 @@ namespace gcu
 class Application;
 class Document;
 
+/*!\class FileChooser gcu/filechooser.h
+This class is used each time a file name must be choosen. It embeds a GtkFileChooserDialog
+window.
+*/
 class FileChooser
 {
 public:
-	FileChooser (Application *App, bool Save, list<char const*> mime_types, Document *pDoc = NULL, char const *title = NULL);
+/*!
+@param App the Application instance owning the dialog.
+@param Save tells if the requested file is to be saved or loaded.
+@param mime_types a std::list of supported mime types.
+@param pDoc the document to save, the parameter is optional when loading.
+Default value is NULL.
+@param title an optional title for the dialog box. Default value is NULL.
+@param extra_widget an optional widget to add to the GtkFileChooserDialog
+window. Default value is NULL.
+
+The constructor shows the GtkFileChooserDialog window, retrieve it's response and calls
+Application::FileProcess if needed. The dialog is modal (nothing else can be done while
+it is opened).
+*/
+	FileChooser (Application *App, bool Save, list<string> mime_types, Document *pDoc = NULL, char const *title = NULL, GtkWidget *extra_widget = NULL);
 	
 private:
 	GtkFileChooser* dialog;
