@@ -1,11 +1,8 @@
-// -*- C++ -*-
-
 /* 
  * Gnome Chemisty Utils
  * chem-viewer.c 
  *
- * Copyright (C) 2005-2006 Jean Bréfort <jean.brefort@normalesup.org>
- *
+ * Copyright (C) 2005-2006
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
  * published by the Free Software Foundation; either version 2 of the
@@ -23,7 +20,10 @@
  */
 
 #include "config.h"
-#include "gcu/gtkchem3dviewer.h"
+#include <gcu/element.h>
+#include <gcu/gtkchem3dviewer.h>
+#include <gcu/gtkcrystalviewer.h>
+#include <gcu/chem3ddoc.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkplug.h>
@@ -33,8 +33,12 @@
 #include <sstream>
 #include <string>
 #include <map>
+#include <cstring>
 
 using namespace std;
+using namespace gcu;
+
+static bool loaded_radii = false;
 
 class ChemComp
 {
@@ -90,7 +94,10 @@ void ChemComp::SetWindow (XID xid)
 			GDK_WINDOW_XID (Plug->window), xid, 0, 0);
 		XMapWindow (GDK_WINDOW_XDISPLAY (Plug->window),
 			GDK_WINDOW_XID (Plug->window));
-		Viewer = gtk_chem3d_viewer_new (NULL);
+		if (MimeType == "application/x-gcrystal")
+			Viewer = gtk_crystal_viewer_new (NULL);
+		else
+			Viewer = gtk_chem3d_viewer_new (NULL);
 		gtk_container_add (GTK_CONTAINER (Plug), Viewer);
 		gtk_widget_show_all (Plug);
 	}
@@ -99,20 +106,31 @@ void ChemComp::SetWindow (XID xid)
 void ChemComp::SetFilename (string& filename)
 {
 	Filename = filename;
-	gtk_chem3d_viewer_set_uri_with_mime_type (GTK_CHEM3D_VIEWER (Viewer),
-			filename.c_str (), MimeType.c_str ());
-	map<string, string>::iterator i, iend = Params.end ();
-	for (i = Params.begin (); i != iend; i++) {
-		if ((*i).first == "display3d") {
-			if ((*i).second == "ball&stick")
-				g_object_set (G_OBJECT (Viewer), "display3d", BALL_AND_STICK, NULL);
-			else if ((*i).second == "spacefill")
-				g_object_set (G_OBJECT (Viewer), "display3d", SPACEFILL, NULL);
+	if (MimeType == "application/x-gcrystal") {
+		if (!loaded_radii) {
+			Element::LoadRadii ();
+			loaded_radii = true;
 		}
-		else
-			g_object_set (G_OBJECT (Viewer), (*i).first.c_str (), (*i).second.c_str (), NULL);
+		xmlDocPtr xml = xmlParseFile (filename.c_str ());
+		if (!xml || !xml->children || strcmp ((char*) xml->children->name, "crystal"))
+			return;
+		gtk_crystal_viewer_set_data (GTK_CRYSTAL_VIEWER (Viewer), xml->children);
+	} else {
+		gtk_chem3d_viewer_set_uri_with_mime_type (GTK_CHEM3D_VIEWER (Viewer),
+				filename.c_str (), MimeType.c_str ());
+		map<string, string>::iterator i, iend = Params.end ();
+		for (i = Params.begin (); i != iend; i++) {
+			if ((*i).first == "display3d") {
+				if ((*i).second == "ball&stick")
+					g_object_set (G_OBJECT (Viewer), "display3d", BALL_AND_STICK, NULL);
+				else if ((*i).second == "spacefill")
+					g_object_set (G_OBJECT (Viewer), "display3d", SPACEFILL, NULL);
+			}
+			else
+				g_object_set (G_OBJECT (Viewer), (*i).first.c_str (), (*i).second.c_str (), NULL);
+		}
+		Params.clear ();
 	}
-	Params.clear ();
 }
 
 GIOChannel *in_channel;
