@@ -4,7 +4,7 @@
  * Gnome Crystal
  * application.cc 
  *
- * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -37,10 +37,11 @@
 #include "prefs.h"
 #include "window.h"
 #include <glib/gi18n.h>
+#include <cstring>
 
 static unsigned short nNewDocs = 1;
 
-gcApplication::gcApplication(): Application ("gcrystal-unstable")
+gcApplication::gcApplication(): Application ("gcrystal")
 {
 }
 
@@ -61,7 +62,7 @@ gcDocument *gcApplication::OnFileNew ()
 
 void gcApplication::OnFileOpen ()
 {
-	list<char const*> l;
+	list<string> l;
 	l.push_front ("application/x-gcrystal");
 	FileChooser (this, false, l);
 }
@@ -78,7 +79,7 @@ void gcApplication::OnFileSave ()
 
 void gcApplication::OnFileSaveAs ()
 {
-	list<char const*> l;
+	list<string> l;
 	l.push_front ("application/x-gcrystal");
 	FileChooser (this, true, l, m_pActiveDoc);
 }
@@ -137,12 +138,12 @@ void gcApplication::OnSaveAsImage ()
 {
 	if (!m_pActiveDoc)
 		return;
-	list<char const*> l;
+	list<string> l;
 	map<string, GdkPixbufFormat*>::iterator i, end = m_SupportedPixbufFormats.end ();
 	for (i = m_SupportedPixbufFormats.begin (); i != end; i++)
 		l.push_front ((*i).first.c_str ());
 	l.push_front ("model/vrml");
-	FileChooser (this, true, l, m_pActiveDoc, _("Save as image"), GetImageResolutionWidget ());
+	FileChooser (this, true, l, m_pActiveDoc, _("Save as image"), GetImageSizeWidget ());
 }
 
 gcDocument* gcApplication::GetDoc (const char* filename)
@@ -160,7 +161,7 @@ gcDocument* gcApplication::GetDoc (const char* filename)
 		return pDoc;
 	if (m_bFileOpening) {
 		pDoc = m_Docs.back ();
-		if (!pDoc->IsEmpty () || pDoc->IsDirty ())
+		if (!pDoc->GetEmpty () || pDoc->GetDirty ())
 			pDoc = NULL;
 	}
 	if (!pDoc) {
@@ -193,10 +194,10 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 		char *ext = NULL;
 		switch (type) {
 		case GCRYSTAL:
-			ext = ".gcrystal";
+			ext = (char*) ".gcrystal";
 			break;
 		case VRML:
-			ext = ".wrl";
+			ext = (char*) ".wrl";
 			break;
 		default:
 			break;
@@ -229,12 +230,13 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 				GtkRecentData data;
 				data.display_name = (char*) Doc->GetTitle ();
 				data.description = NULL;
-				data.mime_type = "application/x-gcrystal";
-				data.app_name = "gcrystal";
-				data.app_exec = "gcrystal %u";
+				data.mime_type = (char*) "application/x-gcrystal";
+				data.app_name = (char*) "gcrystal";
+				data.app_exec = (char*) "gcrystal %u";
 				data.groups = NULL;
 				data.is_private =  FALSE;
 				gtk_recent_manager_add_full (GetRecentManager (), filename2.c_str (), &data);
+				Doc->RenameViews ();
 				break;
 			case VRML:
 				Doc->OnExportVRML (filename2);
@@ -246,12 +248,15 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 	} else {
 		if (strcmp (mime_type, "application/x-gcrystal"))
 			return true;
-		if (!Doc)
-			Doc = GetDoc (filename);
+		gcDocument *xDoc = GetDoc (filename);
+		if (xDoc)
+			Doc = xDoc;
+		else if (!pDoc->GetEmpty () || pDoc->GetDirty ())
+			Doc = NULL;
 		if (!Doc)
 			Doc = OnFileNew ();
 		if (Doc->GetFileName () && !strcmp (Doc->GetFileName(), filename)) {
-			if (!Doc->IsDirty ())
+			if (!Doc->GetDirty ())
 				return true;
 			else {
 				gchar* str = g_strdup_printf (_("\"%s\" has been modified since last saving. Do you wish to come back to saved version?"), Doc->GetTitle ());
@@ -265,17 +270,30 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 			GtkRecentData data;
 			data.display_name = (char*) Doc->GetTitle ();
 			data.description = NULL;
-			data.mime_type = "application/x-gcrystal";
-			data.app_name = "gcrystal";
-			data.app_exec = "gcrystal %u";
+			data.mime_type = (char*) "application/x-gcrystal";
+			data.app_name = (char*) "gcrystal";
+			data.app_exec = (char*) "gcrystal %u";
 			data.groups = NULL;
 			data.is_private =  FALSE;
 			gtk_recent_manager_add_full (GetRecentManager (), filename, &data);
-			// TODO: change titles in every window
-	/*		gtk_label_set_text (pView->GetLabel (), pDoc->GetTitle ());
-			GtkLabel *pLabel = pView->GetMenuLabel ();
-			if (pLabel)
-				gtk_label_set_text (pLabel, pDoc->GetTitle ());*/
+			// change titles in every window and bring to front
+			list <CrystalView *> *Views = Doc->GetViews ();
+			list <CrystalView *>::iterator i, iend = Views->end ();
+			int n = 1, max = Views->size ();
+			char const *title = Doc->GetTitle ();
+			for (i = Views->begin (); i != iend; i++) {
+				gcWindow *window = dynamic_cast <gcView*> (*i)->GetWindow ();
+				GtkWindow *w = window->GetWindow ();
+				gtk_window_present (w);
+				if (max > 1) {
+					char *t = g_strdup_printf ("%s (%i)", title, n++);
+					gtk_window_set_title (w, t);
+					g_free (t);
+				} else
+					gtk_window_set_title (w, title);
+				window->ActivateActionWidget ("ui/MainMenu/FileMenu/Save", !Doc->GetReadOnly ());
+				window->ActivateActionWidget ("ui/MainToolbar/Save", !Doc->GetReadOnly ());
+			}
 		}
 	}
 	return false;
