@@ -30,6 +30,7 @@
 #include "view-settings.h"
 #include <gcu/crystalview.h>
 #include <glib/gi18n.h>
+#include <cstring>
 
 //Callbacks
 static bool on_delete_event (GtkWidget* widget, GdkEvent *event, gcWindow* Win)
@@ -118,6 +119,12 @@ static void on_about (GtkWidget *widget, void *data)
 		"USA";
 /* Note to translators: replace the following string with the appropriate credits for you lang */
 	char *translator_credits = _("translator_credits");
+	GError *error = NULL;
+	GdkPixbuf *logo = gdk_pixbuf_new_from_file (PIXMAPSDIR"/gcrystal_logo.png", &error);
+	if (error) {
+		g_error_free (error);
+		error = NULL;
+	}
 	gtk_show_about_dialog (NULL,
 					"name", _("Gnome Crystal"),
 					"authors", authors,
@@ -125,11 +132,13 @@ static void on_about (GtkWidget *widget, void *data)
 					"comments", _("Gnome Crystal is a lightweight crystal structures viewer for Gnome"),
 					"copyright", _("Copyright © 1999-2007 by Jean Bréfort"),
 					"license", license,
+					"logo", logo,
 					"translator_credits", strcmp (translator_credits, "translator_credits") != 0 ? 
 											(const char *)translator_credits : NULL,
 					"version", VERSION,
 					"website", "http://www.nongnu.org/gchemutils",
 					NULL);
+	g_object_unref (logo);
 }
 
 static void on_lattice(GtkWidget *widget, gcWindow *Win)
